package yb_activity

import (
	"time"
)

// YbActivity 弘则研小程序 活动表
type YbActivity struct {
	ActivityID            int       `gorm:"primaryKey;column:activity_id;type:int(11);not null" json:"activityID"`                                            // 活动ID
	FirstActivityTypeID   int       `gorm:"index:activity_type_id;column:first_activity_type_id;type:int(100);not null;default:0" json:"firstActivityTypeId"` // 第一级的活动类型ID
	FirstActivityTypeName string    `gorm:"column:first_activity_type_name;type:varchar(30);not null;default:''" json:"firstActivityTypeName"`                // 第一级的活动类型名称
	ActivityTypeID        int       `gorm:"column:activity_type_id;type:int(100);not null;default:0" json:"activityTypeId"`                                   // 活动类型ID
	ActivityTypeName      string    `gorm:"column:activity_type_name;type:varchar(30);not null;default:''" json:"activityTypeName"`                           // 活动类型名称
	ActivityName          string    `gorm:"column:activity_name;type:text;not null" json:"activityName"`                                                      // 活动标题
	StartTime             time.Time `gorm:"column:start_time;type:datetime" json:"startTime"`                                                                 // 活动开始时间
	EndTime               time.Time `gorm:"column:end_time;type:datetime" json:"endTime"`                                                                     // 活动结束时间
	Speaker               string    `gorm:"column:speaker;type:varchar(255);not null;default:''" json:"speaker"`                                              // 主讲人
	SpeakerHeadPic        string    `gorm:"column:speaker_head_pic;type:varchar(255);not null;default:''" json:"speakerHeadPic"`                              // 主讲人头像
	SpeakerBackgroundPic  string    `gorm:"column:speaker_background_pic;type:varchar(255);not null;default:''" json:"speakerBackgroundPic"`                  // 主讲人背景图
	MainlandTel           string    `gorm:"column:mainland_tel;type:varchar(255);not null;default:''" json:"mainlandTel"`                                     // 大陆拨入
	HongKongTel           string    `gorm:"column:hong_kong_tel;type:varchar(255);not null;default:''" json:"hongKongTel"`                                    // 香港拨入
	TaiwanTel             string    `gorm:"column:taiwan_tel;type:varchar(255);not null;default:''" json:"taiwanTel"`                                         // 台湾拨入
	AmericaTel            string    `gorm:"column:america_tel;type:varchar(255);not null;default:''" json:"americaTel"`                                       // 美国拨入
	SingaporeTel          string    `gorm:"column:singapore_tel;type:varchar(255);not null;default:''" json:"singaporeTel"`                                   // 新加坡拨入
	ParticipationCode     string    `gorm:"column:participation_code;type:varchar(255);not null;default:''" json:"participationCode"`                         // 参会密码
	LinkParticipants      string    `gorm:"column:link_participants;type:longtext;not null" json:"linkParticipants"`                                          // 参会链接
	IsLimitPeople         int8      `gorm:"index:is_limit_people;column:is_limit_people;type:tinyint(4);not null;default:0" json:"isLimitPeople"`             // 是否限制人数 1是，0否
	LimitPeopleNum        int       `gorm:"column:limit_people_num;type:int(9);not null;default:0" json:"limitPeopleNum"`                                     // 限制人数数量
	ReportID              int       `gorm:"column:report_id;type:int(11);not null;default:0" json:"reportId"`                                                 // 报告链接所关联的文章ID
	ReportLink            string    `gorm:"column:report_link;type:varchar(255);not null;default:''" json:"reportLink"`                                       // 报告链接
	ReportName            string    `gorm:"column:report_name;type:varchar(255);not null;default:''" json:"reportName"`                                       // 报告标题
	City                  string    `gorm:"column:city;type:varchar(255);not null;default:''" json:"city"`                                                    // 城市
	Address               string    `gorm:"column:address;type:varchar(255);not null;default:''" json:"address"`                                              // 活动地址
	Remarks               string    `gorm:"column:remarks;type:text;not null" json:"remarks"`                                                                 // 备注
	UserID                int       `gorm:"column:user_id;type:int(9);not null;default:0" json:"userId"`                                                      // 创建者id
	PublishStatus         int8      `gorm:"index:publish_status;column:publish_status;type:tinyint(4);not null;default:0" json:"publishStatus"`               // 发布状态，0未发布，1已发布
	IsSendWxMsg           int8      `gorm:"column:is_send_wx_msg;type:tinyint(4);not null;default:0" json:"isSendWxMsg"`                                      // 是否推送过会议提醒微信消息，未推送：0，已推送：1
	IsSendSalonWxMsg      int8      `gorm:"column:is_send_salon_wx_msg;type:tinyint(4);not null;default:0" json:"isSendSalonWxMsg"`                           // 是否推送过沙龙提醒微信消息，未推送：0，已推送：1
	IsDelete              int8      `gorm:"column:is_delete;type:tinyint(4);not null;default:0" json:"isDelete"`                                              // 是否删除，0：未删除，1：已删除
	ModifyTime            time.Time `gorm:"column:modify_time;type:timestamp;not null;default:CURRENT_TIMESTAMP" json:"modifyTime"`                           // 修改时间
	CreateTime            time.Time `gorm:"index:create_time;column:create_time;type:datetime;default:CURRENT_TIMESTAMP" json:"createTime"`                   // 创建时间
	IsNewReport           int       `gorm:"column:is_new_report;type:tinyint(4);not null;default:0" json:"isNewReport"`                                       // 是否关联新报告：0-否 1-是
}

// TableName get sql table name.获取数据库表名
func (m *YbActivity) TableName() string {
	return "yb_activity"
}

// YbActivityColumns get sql column name.获取数据库列名
var YbActivityColumns = struct {
	ActivityID            string
	FirstActivityTypeID   string
	FirstActivityTypeName string
	ActivityTypeID        string
	ActivityTypeName      string
	ActivityName          string
	StartTime             string
	EndTime               string
	Speaker               string
	SpeakerHeadPic        string
	SpeakerBackgroundPic  string
	MainlandTel           string
	HongKongTel           string
	TaiwanTel             string
	AmericaTel            string
	SingaporeTel          string
	ParticipationCode     string
	LinkParticipants      string
	IsLimitPeople         string
	LimitPeopleNum        string
	ReportID              string
	ReportLink            string
	ReportName            string
	City                  string
	Address               string
	Remarks               string
	UserID                string
	PublishStatus         string
	IsSendWxMsg           string
	IsSendSalonWxMsg      string
	IsDelete              string
	ModifyTime            string
	CreateTime            string
	IsNewReport           string
}{
	ActivityID:            "activity_id",
	FirstActivityTypeID:   "first_activity_type_id",
	FirstActivityTypeName: "first_activity_type_name",
	ActivityTypeID:        "activity_type_id",
	ActivityTypeName:      "activity_type_name",
	ActivityName:          "activity_name",
	StartTime:             "start_time",
	EndTime:               "end_time",
	Speaker:               "speaker",
	SpeakerHeadPic:        "speaker_head_pic",
	SpeakerBackgroundPic:  "speaker_background_pic",
	MainlandTel:           "mainland_tel",
	HongKongTel:           "hong_kong_tel",
	TaiwanTel:             "taiwan_tel",
	AmericaTel:            "america_tel",
	SingaporeTel:          "singapore_tel",
	ParticipationCode:     "participation_code",
	LinkParticipants:      "link_participants",
	IsLimitPeople:         "is_limit_people",
	LimitPeopleNum:        "limit_people_num",
	ReportID:              "report_id",
	ReportLink:            "report_link",
	ReportName:            "report_name",
	City:                  "city",
	Address:               "address",
	Remarks:               "remarks",
	UserID:                "user_id",
	PublishStatus:         "publish_status",
	IsSendWxMsg:           "is_send_wx_msg",
	IsSendSalonWxMsg:      "is_send_salon_wx_msg",
	IsDelete:              "is_delete",
	ModifyTime:            "modify_time",
	CreateTime:            "create_time",
	IsNewReport:           "is_new_report",
}
